@@ -4,17 +4,10 @@ An atmospheric chemistry box model. Powered by MUSICA.
 This package contains modules for handling various aspects of a music box,
 including species, products, reactants, reactions, and more.
 """
-__version__ = "2.5.2"
+__version__ = "2.5.3"
 
 from .utils import convert_time, convert_pressure, convert_temperature, convert_concentration
-from .species import Species
-from .product import Product
-from .reactant import Reactant
-from .reaction import Reaction, Branched, Arrhenius, Tunneling, Troe_Ternary
-from .species_list import SpeciesList
 from .model_options import BoxModelOptions
-from .species_concentration import SpeciesConcentration
-from .reaction_rate import ReactionRate
 from .conditions import Conditions
 
 from .evolving_conditions import EvolvingConditions
